Module: Lolita::Configuration::Tab

Defined in:
lib/lolita/configuration/tab.rb,
lib/lolita/configuration/tab/content.rb,
lib/lolita/configuration/tab/default.rb

Overview

Tab is used as a container for different type of resource content. It can contain fields, images, audio, video files, maps and other stuff. Tab contain following parts, that also are configurable through block or arguments passed to tab.

  • nested_fields_for Create fields for different DB table/collection than given.
  • field_set Create fields set for ease use in builders.
  • field Create field in tab, fields also can be included in #nested_fields_for and #field_set
  • default_fields To create new tab you should pass Lolita::DBI object and tab type, default is :content ====Example Lolita::Configuration::Tab.new(Lolita::DBI.new(Post),:images) To define tab in ORM model, through lolita configuration do the following ====Example lolita do tab(:files) end

Defined Under Namespace

Classes: Base, Content, Default